# bytetype

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

A simple Byte type

## Install

``` sh
pip install bytetype
```

## Usage

**NOTE** that: - `ByteSize` corresponds to the base numeric value to use
i.e. `1024` - `BytesUnit` corresponds to the string unit to use
i.e. `"KB"`

### Examples
